@@ -38,6 +38,7 @@ from workflowwebtools.predict import evaluate
 
 from workflowwebtools import statuses
 
+from cmstoolbox.emailtools import send_email
 
 class WorkflowTools(object):
 
@@ -1008,6 +1009,12 @@ class WorkflowTools(object):
         return {}
 
 
+    @cherrypy.expose
+    @cherrypy.tools.json_out()
+    def assistance_manual_recovered(self):
+        return errorutils.assistance_manual('assistance-manual-recovered')
+
+
     @cherrypy.expose
     @cherrypy.tools.json_out()
     def assistance_manual(self):
@@ -1017,6 +1024,8 @@ class WorkflowTools(object):
     @cherrypy.expose
     def check_auto_acdc(self, key):
 
+        submitted = []
+
         if key == serverconfig.config_dict()['actions']['key']:
 
             aieh_config = serverconfig.config_dict()['aieh']
@@ -1032,11 +1041,26 @@ class WorkflowTools(object):
                 params = self.auto_acdc(workflow)
 
                 if params:
-                    if dry:
-                        print(workflow)
-                    else:
+                    if not dry:
                         manageactions.submit2(user, [params])
+                    submitted.append(workflow)
 
             self.update_statuses()
+        
+        if len(submitted):
+            unified = "https://cms-unified.web.cern.ch/cms-unified/report/"
+            wm_email = serverconfig.config_dict()['webmaster']['email']
+            message_text = (
+                'Hi'+'\n\n'
+                'Here is the list of workflows automatically submitted by console \n\n' +
+                '\n'.join([ unified+s for s in submitted]) +
+                '\n\n' +
+                'Tools and Integration'
+                )
 
-        return 'Done'
+            email = 'cms-comp-ops-toolsandint@cern.ch'
+            send_email(wm_email, [email, wm_email , 'hbakhshi@cern.ch'],
+                       'Automatic actions',
+                       message_text , method='smtplib')
+
+        return '\n'.join(submitted)
